@@ -1,9 +1,8 @@
 #
 # bool2str.rb
 #
-
 module Puppet::Parser::Functions
-  newfunction(:bool2str, :type => :rvalue, :doc => <<-EOS
+  newfunction(:bool2str, :type => :rvalue, :doc => <<-DOC
     Converts a boolean to a string using optionally supplied arguments. The
     optional second and third arguments represent what true and false will be
     converted to respectively. If only one argument is given, it will be
@@ -16,12 +15,11 @@ module Puppet::Parser::Functions
     bool2str(false, 't', 'f')         => 'f'
 
     Requires a single boolean as an input.
-    EOS
-  ) do |arguments|
+    DOC
+             ) do |arguments|
 
-    unless arguments.size == 1 or arguments.size == 3
-      raise(Puppet::ParseError, "bool2str(): Wrong number of arguments " +
-                                "given (#{arguments.size} for 3)")
+    unless arguments.size == 1 || arguments.size == 3
+      raise(Puppet::ParseError, "bool2str(): Wrong number of arguments given (#{arguments.size} for 3)")
     end
 
     value = arguments[0]
@@ -34,8 +32,8 @@ module Puppet::Parser::Functions
       raise(Puppet::ParseError, 'bool2str(): Requires a boolean to work with')
     end
 
-    unless [true_string, false_string].all?{|x| x.kind_of?(String)}
-      raise(Puppet::ParseError, "bool2str(): Requires strings to convert to" )
+    unless [true_string, false_string].all? { |x| x.is_a?(String) }
+      raise(Puppet::ParseError, 'bool2str(): Requires strings to convert to')
     end
 
     return value ? true_string : false_string
