@@ -1,6 +1,8 @@
+#
+# getvar.rb
+#
 module Puppet::Parser::Functions
-
-  newfunction(:getvar, :type => :rvalue, :doc => <<-'ENDHEREDOC') do |args|
+  newfunction(:getvar, :type => :rvalue, :doc => <<-'DOC') do |args|
     Lookup a variable in a remote namespace.
 
     For example:
@@ -13,23 +15,21 @@ module Puppet::Parser::Functions
         $datalocation = 'site::data'
         $bar = getvar("${datalocation}::bar")
         # Equivalent to $bar = $site::data::bar
-    ENDHEREDOC
+    DOC
 
     unless args.length == 1
-      raise Puppet::ParseError, ("getvar(): wrong number of arguments (#{args.length}; must be 1)")
+      raise Puppet::ParseError, "getvar(): wrong number of arguments (#{args.length}; must be 1)"
     end
 
     begin
       result = nil
       catch(:undefined_variable) do
-        result = self.lookupvar("#{args[0]}")
+        result = lookupvar((args[0]).to_s)
       end
 
       # avoid relying on incosistent behaviour around ruby return values from catch
       result
-    rescue Puppet::ParseError # Eat the exception if strict_variables = true is set
+    rescue Puppet::ParseError # rubocop:disable Lint/HandleExceptions : Eat the exception if strict_variables = true is set
     end
-
   end
-
 end
