@@ -1,21 +1,19 @@
 #
 # hash.rb
 #
-
 module Puppet::Parser::Functions
-  newfunction(:hash, :type => :rvalue, :doc => <<-EOS
-This function converts an array into a hash.
+  newfunction(:hash, :type => :rvalue, :doc => <<-DOC
+    This function converts an array into a hash.
 
-*Examples:*
+    *Examples:*
 
-    hash(['a',1,'b',2,'c',3])
+        hash(['a',1,'b',2,'c',3])
 
-Would return: {'a'=>1,'b'=>2,'c'=>3}
-    EOS
-  ) do |arguments|
+    Would return: {'a'=>1,'b'=>2,'c'=>3}
+    DOC
+             ) do |arguments|
 
-    raise(Puppet::ParseError, "hash(): Wrong number of arguments " +
-      "given (#{arguments.size} for 1)") if arguments.size < 1
+    raise(Puppet::ParseError, "hash(): Wrong number of arguments given (#{arguments.size} for 1)") if arguments.empty?
 
     array = arguments[0]
 
@@ -30,8 +28,7 @@ Would return: {'a'=>1,'b'=>2,'c'=>3}
       array  = array.flatten
       result = Hash[*array]
     rescue StandardError
-      raise(Puppet::ParseError, 'hash(): Unable to compute ' +
-        'hash from array given')
+      raise(Puppet::ParseError, 'hash(): Unable to compute hash from array given')
     end
 
     return result
