@@ -1,6 +1,8 @@
+#
+# validate_slength.rb
+#
 module Puppet::Parser::Functions
-
-  newfunction(:validate_slength, :doc => <<-'ENDHEREDOC') do |args|
+  newfunction(:validate_slength, :doc => <<-'DOC') do |args|
     Validate that the first argument is a string (or an array of strings), and
     less/equal to than the length of the second argument. An optional third
     parameter can be given the minimum length. It fails if the first
@@ -19,11 +21,12 @@ module Puppet::Parser::Functions
       validate_slength(["discombobulate","thermometer"],5)
       validate_slength(["discombobulate","moo"],17,10)
 
-    ENDHEREDOC
+    DOC
 
-    function_deprecation([:validate_slength, 'This method is deprecated, please use the stdlib validate_legacy function, with String[]. There is further documentation for validate_legacy function in the README.'])
+    function_deprecation([:validate_slength, 'This method is deprecated, please use the stdlib validate_legacy function,
+                            with String[]. There is further documentation for validate_legacy function in the README.'])
 
-    raise Puppet::ParseError, "validate_slength(): Wrong number of arguments (#{args.length}; must be 2 or 3)" unless args.length == 2 or args.length == 3
+    raise Puppet::ParseError, "validate_slength(): Wrong number of arguments (#{args.length}; must be 2 or 3)" unless args.length == 2 || args.length == 3
 
     input, max_length, min_length = *args
 
@@ -38,17 +41,17 @@ module Puppet::Parser::Functions
       begin
         min_length = Integer(min_length)
         raise ArgumentError if min_length < 0
-    rescue ArgumentError, TypeError
+      rescue ArgumentError, TypeError
         raise Puppet::ParseError, "validate_slength(): Expected third argument to be unset or a positive Numeric, got #{min_length}:#{min_length.class}"
       end
     else
       min_length = 0
     end
 
-    raise Puppet::ParseError, "validate_slength(): Expected second argument to be equal to or larger than third argument" unless max_length >= min_length
+    raise Puppet::ParseError, 'validate_slength(): Expected second argument to be equal to or larger than third argument' unless max_length >= min_length
 
-    validator = lambda do |str|
-      unless str.length <= max_length and str.length >= min_length
+    validator = ->(str) do
+      unless str.length <= max_length && str.length >= min_length
         raise Puppet::ParseError, "validate_slength(): Expected length of #{input.inspect} to be between #{min_length} and #{max_length}, was #{input.length}"
       end
     end
@@ -58,11 +61,8 @@ module Puppet::Parser::Functions
       validator.call(input)
     when Array
       input.each_with_index do |arg, pos|
-        if arg.is_a? String
-          validator.call(arg)
-        else
-          raise Puppet::ParseError, "validate_slength(): Expected element at array position #{pos} to be a String, got #{arg.class}"
-        end
+        raise Puppet::ParseError, "validate_slength(): Expected element at array position #{pos} to be a String, got #{arg.class}" unless arg.is_a? String
+        validator.call(arg)
       end
     else
       raise Puppet::ParseError, "validate_slength(): Expected first argument to be a String or Array, got #{input.class}"
