@@ -1,6 +1,8 @@
+#
+# validate_String.rb
+#
 module Puppet::Parser::Functions
-
-  newfunction(:validate_string, :doc => <<-'ENDHEREDOC') do |args|
+  newfunction(:validate_string, :doc => <<-'DOC') do |args|
     Validate that all passed values are string data structures. Abort catalog
     compilation if any value fails this check.
 
@@ -21,21 +23,20 @@ module Puppet::Parser::Functions
           fail('...')
         }
 
-    ENDHEREDOC
+    DOC
 
-    function_deprecation([:validate_string, 'This method is deprecated, please use the stdlib validate_legacy function, with Stdlib::Compat::String. There is further documentation for validate_legacy function in the README.'])
+    function_deprecation([:validate_string, 'This method is deprecated, please use the stdlib validate_legacy function,
+                            with Stdlib::Compat::String. There is further documentation for validate_legacy function in the README.'])
 
-    unless args.length > 0 then
-      raise Puppet::ParseError, ("validate_string(): wrong number of arguments (#{args.length}; must be > 0)")
+    if args.empty?
+      raise Puppet::ParseError, "validate_string(): wrong number of arguments (#{args.length}; must be > 0)"
     end
 
     args.each do |arg|
       # when called through the v4 API shim, undef gets translated to nil
       unless arg.is_a?(String) || arg.nil?
-        raise Puppet::ParseError, ("#{arg.inspect} is not a string.  It looks to be a #{arg.class}")
+        raise Puppet::ParseError, "#{arg.inspect} is not a string.  It looks to be a #{arg.class}"
       end
     end
-
   end
-
 end
