@@ -1,17 +1,16 @@
 #! /usr/bin/env ruby -S rspec
 require 'spec_helper_acceptance'
 
-describe 'base64 function', :unless => UNSUPPORTED_PLATFORMS.include?(fact('operatingsystem')) do
+describe 'base64 function' do
   describe 'success' do
-    it 'should encode then decode a string' do
-      pp = <<-EOS
+    pp = <<-DOC
       $encodestring = base64('encode', 'thestring')
       $decodestring = base64('decode', $encodestring)
       notify { $decodestring: }
-      EOS
-
+    DOC
+    it 'encodes then decode a string' do
       apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stdout).to match(/thestring/)
+        expect(r.stdout).to match(%r{thestring})
       end
     end
   end
