@@ -1,43 +1,42 @@
 #! /usr/bin/env ruby -S rspec
 require 'spec_helper_acceptance'
 
-describe 'concat function', :unless => UNSUPPORTED_PLATFORMS.include?(fact('operatingsystem')) do
+describe 'concat function' do
   describe 'success' do
-    it 'should concat one array to another' do
-      pp = <<-EOS
+    pp1 = <<-DOC
       $output = concat(['1','2','3'],['4','5','6'])
       validate_array($output)
       if size($output) != 6 {
         fail("${output} should have 6 elements.")
       }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    DOC
+    it 'concats one array to another' do
+      apply_manifest(pp1, :catch_failures => true)
     end
-    it 'should concat arrays and primitives to array' do
-      pp = <<-EOS
+
+    pp2 = <<-DOC
       $output = concat(['1','2','3'],'4','5','6',['7','8','9'])
       validate_array($output)
       if size($output) != 9 {
         fail("${output} should have 9 elements.")
       }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    DOC
+    it 'concats arrays and primitives to array' do
+      apply_manifest(pp2, :catch_failures => true)
     end
-    it 'should concat multiple arrays to one' do
-      pp = <<-EOS
+
+    pp3 = <<-DOC
       $output = concat(['1','2','3'],['4','5','6'],['7','8','9'])
       validate_array($output)
       if size($output) != 9 {
         fail("${output} should have 9 elements.")
       }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    DOC
+    it 'concats multiple arrays to one' do
+      apply_manifest(pp3, :catch_failures => true)
     end
-    it 'should concat hash arguments' do
-      pp = <<-EOS
+
+    pp4 = <<-DOC
       $output = concat([{"a" => "b"}], {"c" => "d", "e" => "f"})
       validate_array($output)
       if size($output) != 2 {
@@ -46,9 +45,9 @@ describe 'concat function', :unless => UNSUPPORTED_PLATFORMS.include?(fact('oper
       if $output[1] != {"c" => "d", "e" => "f"} {
         fail("${output} does not have the expected hash for the second element.")
       }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    DOC
+    it 'concats hash arguments' do
+      apply_manifest(pp4, :catch_failures => true)
     end
   end
 end
