@@ -1,10 +1,9 @@
 #! /usr/bin/env ruby -S rspec
 require 'spec_helper_acceptance'
 
-describe 'defined_with_params function', :unless => UNSUPPORTED_PLATFORMS.include?(fact('operatingsystem')) do
+describe 'defined_with_params function' do
   describe 'success' do
-    it 'should successfully notify' do
-      pp = <<-EOS
+    pp = <<-DOC
       user { 'dan':
         ensure => present,
       }
@@ -12,10 +11,10 @@ describe 'defined_with_params function', :unless => UNSUPPORTED_PLATFORMS.includ
       if defined_with_params(User[dan], {'ensure' => 'present' }) {
         notify { 'User defined with ensure=>present': }
       }
-      EOS
-
+    DOC
+    it 'successfullies notify' do
       apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stdout).to match(/Notice: User defined with ensure=>present/)
+        expect(r.stdout).to match(%r{Notice: User defined with ensure=>present})
       end
     end
   end
