@@ -1,18 +1,17 @@
 #! /usr/bin/env ruby -S rspec
 require 'spec_helper_acceptance'
 
-describe 'delete_at function', :unless => UNSUPPORTED_PLATFORMS.include?(fact('operatingsystem')) do
+describe 'delete_at function' do
   describe 'success' do
-    it 'should delete elements of the array' do
-      pp = <<-EOS
+    pp = <<-DOC
       $output = delete_at(['a','b','c','b'], 1)
       if $output == ['a','c','b'] {
         notify { 'output correct': }
       }
-      EOS
-
+    DOC
+    it 'deletes elements of the array' do
       apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stdout).to match(/Notice: output correct/)
+        expect(r.stdout).to match(%r{Notice: output correct})
       end
     end
   end
