@@ -3,23 +3,23 @@ require 'spec_helper_acceptance'
 
 describe 'ensure_resource function' do
   describe 'success' do
-    it 'ensures a resource already declared' do
-      apply_manifest('')
-      pp = <<-EOS
+    pp1 = <<-DOC
       notify { "test": loglevel => 'err' }
       ensure_resource('notify', 'test', { 'loglevel' => 'err' })
-      EOS
+    DOC
+    it 'ensures a resource already declared' do
+      apply_manifest('')
 
-      apply_manifest(pp, :expect_changes => true)
+      apply_manifest(pp1, :expect_changes => true)
     end
 
+    pp2 = <<-DOC
+      ensure_resource('notify', 'test', { 'loglevel' => 'err' })
+    DOC
     it 'ensures a undeclared resource' do
       apply_manifest('')
-      pp = <<-EOS
-      ensure_resource('notify', 'test', { 'loglevel' => 'err' })
-      EOS
 
-      apply_manifest(pp, :expect_changes => true)
+      apply_manifest(pp2, :expect_changes => true)
     end
     it 'takes defaults arguments'
   end
