@@ -1,16 +1,15 @@
 #! /usr/bin/env ruby -S rspec
 require 'spec_helper_acceptance'
 
-describe 'min function', :unless => UNSUPPORTED_PLATFORMS.include?(fact('operatingsystem')) do
+describe 'min function' do
   describe 'success' do
-    it 'mins arrays' do
-      pp = <<-EOS
+    pp = <<-DOC
       $o = min("the","public","art","galleries")
       notice(inline_template('min is <%= @o.inspect %>'))
-      EOS
-
+    DOC
+    it 'mins arrays' do
       apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stdout).to match(/min is "art"/)
+        expect(r.stdout).to match(%r{min is "art"})
       end
     end
   end
