@@ -1,29 +1,28 @@
 #! /usr/bin/env ruby -S rspec
 require 'spec_helper_acceptance'
 
-describe 'rstrip function', :unless => UNSUPPORTED_PLATFORMS.include?(fact('operatingsystem')) do
+describe 'rstrip function' do
   describe 'success' do
-    it 'rstrips arrays' do
-      pp = <<-EOS
+    pp1 = <<-DOC
       $a = ["  the   ","   public   ","   art","galleries   "]
       # Anagram: Large picture halls, I bet
       $o = rstrip($a)
       notice(inline_template('rstrip is <%= @o.inspect %>'))
-      EOS
-
-      apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stdout).to match(/rstrip is \["  the", "   public", "   art", "galleries"\]/)
+    DOC
+    it 'rstrips arrays' do
+      apply_manifest(pp1, :catch_failures => true) do |r|
+        expect(r.stdout).to match(%r{rstrip is \["  the", "   public", "   art", "galleries"\]})
       end
     end
-    it 'rstrips strings' do
-      pp = <<-EOS
+
+    pp2 = <<-DOC
       $a = "   blowzy night-frumps vex'd jack q   "
       $o = rstrip($a)
       notice(inline_template('rstrip is <%= @o.inspect %>'))
-      EOS
-
-      apply_manifest(pp, :catch_failures => true) do |r|
-        expect(r.stdout).to match(/rstrip is "   blowzy night-frumps vex'd jack q"/)
+    DOC
+    it 'rstrips strings' do
+      apply_manifest(pp2, :catch_failures => true) do |r|
+        expect(r.stdout).to match(%r{rstrip is "   blowzy night-frumps vex'd jack q"})
       end
     end
   end
