@@ -1,33 +1,32 @@
 #! /usr/bin/env ruby -S rspec
 require 'spec_helper_acceptance'
 
-describe 'validate_array function', :unless => UNSUPPORTED_PLATFORMS.include?(fact('operatingsystem')) do
+describe 'validate_array function' do
   describe 'success' do
-    it 'validates a single argument' do
-      pp = <<-EOS
+    pp1 = <<-DOC
       $one = ['a', 'b']
       validate_array($one)
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    DOC
+    it 'validates a single argument' do
+      apply_manifest(pp1, :catch_failures => true)
     end
-    it 'validates an multiple arguments' do
-      pp = <<-EOS
+
+    pp2 = <<-DOC
       $one = ['a', 'b']
       $two = [['c'], 'd']
       validate_array($one,$two)
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    DOC
+    it 'validates an multiple arguments' do
+      apply_manifest(pp2, :catch_failures => true)
     end
     [
       %{validate_array({'a' => 'hash' })},
       %{validate_array('string')},
       %{validate_array(false)},
-      %{validate_array(undef)}
+      %{validate_array(undef)},
     ].each do |pp|
       it "rejects #{pp.inspect}" do
-        expect(apply_manifest(pp, :expect_failures => true).stderr).to match(/is not an Array\.  It looks to be a/)
+        expect(apply_manifest(pp, :expect_failures => true).stderr).to match(%r{is not an Array\.  It looks to be a})
       end
     end
   end
