@@ -4,6 +4,6 @@ require 'rspec'
 class Object
   # This is necessary because the RAL has a 'should'
   # method.
-  alias :must :should
-  alias :must_not :should_not
+  alias must should
+  alias must_not should_not
 end
