@@ -1,7 +1,7 @@
 require 'spec_helper'
 
 if Puppet::Util::Package.versioncmp(Puppet.version, '4.5.0') >= 0
-  describe 'Stdlib::Compat::Ip_address' do
+  describe 'Stdlib::Ip_address' do
     describe 'accepts ipv4 and ipv6 addresses' do
       [
         '224.0.0.0',
@@ -18,10 +18,22 @@ if Puppet::Util::Package.versioncmp(Puppet.version, '4.5.0') >= 0
     end
     describe 'rejects other values' do
       [
+        nil,
+        [nil],
+        [nil, nil],
+        { 'foo' => 'bar' },
+        {},
+        '',
         'nope',
         '77',
         '4.4.4',
         '2001:0db8:85a3:000000:0000:8a2e:0370:7334',
+        '2001::0db8::1',
+        ' 2001:0db8::1',
+        '2001:0db8::1 ',
+        ' 2001:0db8::1 ',
+        'foobar2001:0db8::1',
+        '2001:0db8::1foobar',
       ].each do |value|
         describe value.inspect do
           it { is_expected.not_to allow_value(value) }
